@@ -1,3 +1,6 @@
+#
+# Copyright 2010 Ruediger Gad <r.c.g@gmx.de>
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -16,10 +19,20 @@
 useAlt = False
 altButton = "B"
 
+# Define default mappings for Zeemotes.
+defaultMappings={
+    1: "A",
+    2: "B",
+    3: "C",
+    4: "D"
+    }
+
 # Some useful key names:
 #   Up, Down, Left, Right  (D-pad)
 #   Return (this is also the central button of the D-pad)
 #   Escape
+#   space
+#   Shift_L
 #   F6  (Fullscreen key)
 #   F7  (Zoom/volume -)
 #   F8  (Zoom/volume +) 
@@ -69,9 +82,9 @@ mappingD={
     }
 
 mappingE={
-    'A': ["a d"],    
-    'B': ["a w"],  
-    'C': ["a a"],       
+    'A': ["a Shift_L"],    
+    'B': ["a space"],  
+    'C': ["a w"],       
     'D': ["a s"],   
     'GU': ["a Up"],
     'GD': ["a Down"],
