@@ -16,14 +16,16 @@
 
 import hildon
 import gtk
+import shutil
 
 from ZeeButton import ZeeButton
+from ZeecontrolMenu import ZeecontrolMenu
 from Zeemote import ZeeDiscover
 
 class ZeecontrolGUI(hildon.Program):
   def __init__(self):
     hildon.Program.__init__(self)
-    self.window = hildon.Window()
+    self.window = hildon.StackableWindow()
     self.window.connect("destroy", gtk.main_quit)  
     self.add_window(self.window)
 
@@ -58,51 +60,36 @@ class ZeecontrolGUI(hildon.Program):
     vbox.pack_start(buttonBox2)
     buttonBox2.show()
 
-    self.buttonA = gtk.Button("A")
-    self.buttonA.connect("clicked", self.setMapping, "A")
-    buttonBox1.pack_start(self.buttonA, True, True, 0)
-    self.buttonA.show()
+    for i in ['A', 'B', 'C', 'D']:
+      button = gtk.Button(i)
+      button.connect("clicked", self.setMapping, i)
+      buttonBox1.pack_start(button, True, True, 0)
+      button.show()
 
-    self.buttonB = gtk.Button("B")
-    self.buttonB.connect("clicked", self.setMapping, "B")
-    buttonBox1.pack_start(self.buttonB, True, True, 0)
-    self.buttonB.show()
+    for i in ['E', 'F', 'G', 'H']:
+      button = gtk.Button(i)
+      button.connect("clicked", self.setMapping, i)
+      buttonBox2.pack_start(button, True, True, 0)
+      button.show()
 
-    self.buttonC = gtk.Button("C")
-    self.buttonC.connect("clicked", self.setMapping, "C")
-    buttonBox1.pack_start(self.buttonC, True, True, 0)
-    self.buttonC.show()
-
-    self.buttonD = gtk.Button("D")
-    self.buttonD.connect("clicked", self.setMapping, "D")
-    buttonBox1.pack_start(self.buttonD, True, True, 0)
-    self.buttonD.show()
-
-    self.buttonE = gtk.Button("E")
-    self.buttonE.connect("clicked", self.setMapping, "E")
-    buttonBox2.pack_start(self.buttonE, True, True, 0)
-    self.buttonE.show()
-
-    self.buttonF = gtk.Button("F")
-    self.buttonF.connect("clicked", self.setMapping, "F")
-    buttonBox2.pack_start(self.buttonF, True, True, 0)
-    self.buttonF.show()
-
-    self.buttonG = gtk.Button("G")
-    self.buttonG.connect("clicked", self.setMapping, "G")
-    buttonBox2.pack_start(self.buttonG, True, True, 0)
-    self.buttonG.show()
-
-    self.buttonH = gtk.Button("H")
-    self.buttonH.connect("clicked", self.setMapping, "H")
-    buttonBox2.pack_start(self.buttonH, True, True, 0)
-    self.buttonH.show()
+    self.menu = ZeecontrolMenu(self)
         
+    stack = hildon.WindowStack.get_default()
+    stack.push(self.window)
     self.window.show_all()
 
     while gtk.events_pending():
       gtk.main_iteration()                
-   
+ 
+  def finishShutdown(self):
+    self.selectedZeeButton.safeMappings()
+
+  def getWindow(self):
+    return self.window
+
+  def getZeeButton(self):
+    return self.selectedZeeButton
+
   def setMapping(self, widget, newMapping=None):
     self.selectedZeeButton.setMapping(newMapping)
 
