@@ -39,10 +39,10 @@ class ZeecontrolMenu():
     self.menu = hildon.AppMenu()
     
     title = "Edit Mapping"
-    self.addButton(title, open_mapping_settings, app.getZeeButton().getMapping)
+    self.addButton(title, open_mapping_settings, self.app)
 
     title = "Edit Alternate Mapping"
-    self.addButton(title, open_mapping_settings, app.getZeeButton().getAltMapping)
+    self.addButton(title, open_alt_mapping_settings, self.app)
 
     self.addToggleButton("Use Alternate Mapping", set_use_alt)
 
@@ -51,11 +51,11 @@ class ZeecontrolMenu():
     self.menu.show_all()
     self.app.getWindow().set_app_menu(self.menu)
 
-  def addButton(self, title, callback, method=None):
+  def addButton(self, title, callback, app=None):
     button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
     button.set_label(title)
-    if method :
-      button.connect("clicked", callback, title, method)
+    if app :
+      button.connect("clicked", callback, title, app)
     else:
       button.connect("clicked", callback, title)
 
