@@ -13,15 +13,19 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+import dbus
+import gconf
 import gtk
 import os
 import sys
 from threading import Thread
+import time
 
 from XControl import XControl
 from Zeemote import ZeeDiscover, Zeemote, buttonmap
 
-# If a user config directoryis present try to load mappings
+# If a user config directory is present try to load mappings
 # from there.
 userConfigPath = os.getenv("HOME") + "/.zeecontrol"
 sys.path.append(userConfigPath)
@@ -59,6 +63,12 @@ class ZeemoteEventThread(Thread):
       'GR': [False]
       }
 
+    bus = dbus.SystemBus()
+    mceObj = bus.get_object("com.nokia.mce", "/com/nokia/mce/request")
+    self.mceIf = dbus.Interface(mceObj, "com.nokia.mce.request")
+    displayTimeout = gconf.client_get_default().get_int("/apps/osso/applet/osso-applet-display/brightness_period") 
+    self.timeout = displayTimeout * 0.5
+
   def run(self):
     buttons='ABCD'
     xpon=False
@@ -71,12 +81,23 @@ class ZeemoteEventThread(Thread):
     self.zee = discover.getZeemote( (self.zeeBtn.getId() - 1) )
     state = self.zee.getState()
 
+    timestamp = time.time()
+    self.mceIf.req_tklock_mode_change("unlocked")
     self.zeeBtn.signalConnected()
 
     while state.isConnected() :
       self.zee.waitForData()
       state = self.zee.getState()
 
+      # This hack is used to avoid the system going into standby mode.
+      # This is needed because the xtest events used by zeecontrol for 
+      # "emulating" keyboard actions etc. seem not to be taken as "real" 
+      # user input, hence the standby timeout is not being reset.
+      currentTime = time.time()
+      if (currentTime - timestamp) > self.timeout:
+        timestamp = currentTime
+        self.mceIf.req_tklock_mode_change("unlocked")
+
 #      print "button mask %d" % state.getButtonMask()
 
       # Adjust sign and axis association here in order
